﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

using System;

namespace Microsoft.CodeAnalysis.SQLite.Interop
{
    internal class SqlException(Result result, string message) : Exception(message)
    {
        public readonly Result Result = result;
    }
}
